changeset 27012:f9a9ffebe2c0 v8.2.4035

patch 8.2.4035: timer triggered at the debug prompt may cause trouble Commit: https://github.com/vim/vim/commit/48d0ac775cb2da3b5aa9d46711ff17c50ce0f707 Author: Bram Moolenaar <Bram@vim.org> Date: Fri Jan 7 20:40:08 2022 +0000 patch 8.2.4035: timer triggered at the debug prompt may cause trouble Problem: Timer triggered at the debug prompt may cause trouble. Solution: Do not trigger any timer at the debug prompt. (closes https://github.com/vim/vim/issues/9481)
author Bram Moolenaar <Bram@vim.org>
date Fri, 07 Jan 2022 21:45:03 +0100
parents f9d3d0c55a78
children 056f7574147c
files src/time.c src/version.c
diffstat 2 files changed, 5 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -751,6 +751,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    4035,
+/**/
     4034,
 /**/
     4033,
--- a/src/time.c
+++ b/src/time.c
@@ -501,8 +501,9 @@ check_due_timer(void)
     int		need_update_screen = FALSE;
     long	current_id = last_timer_id;
 
-    // Don't run any timers while exiting or dealing with an error.
-    if (exiting || aborting())
+    // Don't run any timers while exiting, dealing with an error or at the
+    // debug prompt.
+    if (exiting || aborting() || debug_mode)
 	return next_due;
 
     profile_start(&now);